@@ -5,8 +5,9 @@ from aiokafka import AIOKafkaProducer
 
 from async_tools import AsyncOnStart, AsyncOnStop
 
-from notification_server_connector.models.notification import Notification, SourceTypes
+from notification_server_connector.utils.exceptions import NotificationsServerError
 from notification_server_connector.utils.abstract_encoder import AbstractEncoder
+from notification_server_connector.models.notification import Notification, SourceTypes
 
 
 logger = Logger(__name__)
@@ -31,7 +32,7 @@ class NotificationConnector(AsyncOnStart, AsyncOnStop):
     def __init__(self, config: Config, context: Context) -> None:
         self._config = config
         self._context = context
-        self._http_client = aiohttp.ClientSession()
+        self._http_client = aiohttp.ClientSession(config.url)
 
     async def _on_start(self) -> None:
         self._producer = AIOKafkaProducer(
@@ -61,12 +62,12 @@ class NotificationConnector(AsyncOnStart, AsyncOnStop):
         source_ids: list[int],
         server_name: str = 'unknown',
         timeout: int = 5
-    ) -> None:
-        logger.debug(
+    ) -> bool:
+        logger.info(
             f'mark notification for user({user_id}) as read for sources({source_type}): {source_ids}'
         )
         async with self._http_client.post(
-            f'{self._config.url}/v1/mark_notifications_as_read_internal',
+            '/v1/mark_notifications_as_read_internal',
             json={
                 'user_id': user_id,
                 'source_type': source_type,
@@ -77,8 +78,15 @@ class NotificationConnector(AsyncOnStart, AsyncOnStop):
             },
             timeout=timeout,
         ) as response:
-            logger.debug(
+            logger.info(
                 f'mark notification as read done, status: {response.status} {response.reason}'
             )
-            response.raise_for_status()
-            return await response.json()
+
+            answer = await response.json()
+            done = answer.get('done', False)
+            result = answer.get('result', False)
+            error = answer.get('error', None)
+            if not done:
+                logger.error(f'mark notification as read failed, error: {error}')
+                raise NotificationsServerError(f'mark notification as read failed, error: {error}')
+            return result
